==> tf_shell-0.1.5-cp311-cp311-manylinux_2_35_x86_64.whl: tf_shell/__init__.py <==
#!/usr/bin/python
#
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import

from tf_shell.python.shell_tensor import ShellTensor64
from tf_shell.python.shell_tensor import mod_reduce_tensor64
from tf_shell.python.shell_tensor import to_shell_plaintext
from tf_shell.python.shell_tensor import to_encrypted
from tf_shell.python.shell_tensor import to_tensorflow
from tf_shell.python.shell_tensor import roll
from tf_shell.python.shell_tensor import reduce_sum
from tf_shell.python.shell_tensor import fast_reduce_sum
from tf_shell.python.shell_tensor import matmul
from tf_shell.python.shell_tensor import expand_dims
from tf_shell.python.shell_tensor import reshape
from tf_shell.python.shell_tensor import broadcast_to
from tf_shell.python.shell_tensor import segment_sum

from tf_shell.python.shell_context import ShellContext64
from tf_shell.python.shell_context import create_context64
from tf_shell.python.shell_context import mod_reduce_context64
from tf_shell.python.shell_context import create_autocontext64

from tf_shell.python.shell_key import ShellKey64
from tf_shell.python.shell_key import create_key64
from tf_shell.python.shell_key import mod_reduce_key64

from tf_shell.python.shell_key import ShellRotationKey64
from tf_shell.python.shell_key import create_rotation_key64
from tf_shell.python.shell_key import ShellFastRotationKey64
from tf_shell.python.shell_key import create_fast_rotation_key64

==> tf_shell-0.1.23-cp311-cp311-manylinux_2_35_x86_64.whl: tf_shell/__init__.py <==
#!/usr/bin/python
#
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import

from tf_shell.python.shell_tensor import ShellTensor64
from tf_shell.python.shell_tensor import mod_reduce_tensor64
from tf_shell.python.shell_tensor import to_shell_plaintext
from tf_shell.python.shell_tensor import to_encrypted
from tf_shell.python.shell_tensor import to_tensorflow
from tf_shell.python.shell_tensor import roll
from tf_shell.python.shell_tensor import reduce_sum
from tf_shell.python.shell_tensor import fast_reduce_sum
from tf_shell.python.shell_tensor import reduce_sum_with_mod
from tf_shell.python.shell_tensor import matmul
from tf_shell.python.shell_tensor import expand_dims
from tf_shell.python.shell_tensor import reshape
from tf_shell.python.shell_tensor import shape
from tf_shell.python.shell_tensor import broadcast_to
from tf_shell.python.shell_tensor import split
from tf_shell.python.shell_tensor import concat
from tf_shell.python.shell_tensor import segment_sum
from tf_shell.python.shell_tensor import conv2d
from tf_shell.python.shell_tensor import conv2d_transpose
from tf_shell.python.shell_tensor import max_unpool2d
from tf_shell.python.shell_tensor import enable_randomized_rounding

from tf_shell.python.shell_context import ShellContext64
from tf_shell.python.shell_context import create_context64
from tf_shell.python.shell_context import create_autocontext64

from tf_shell.python.shell_key import ShellKey64
from tf_shell.python.shell_key import create_key64
from tf_shell.python.shell_key import ShellRotationKey64
from tf_shell.python.shell_key import create_rotation_key64
from tf_shell.python.shell_key import ShellFastRotationKey64
from tf_shell.python.shell_key import create_fast_rotation_key64

from tf_shell.python.shell_ops import clip_and_noise_features_party
from tf_shell.python.shell_ops import clip_and_noise_labels_party

from tf_shell.python.shell_optimizers import enable_optimization
from tf_shell.python.shell_optimizers import optimize_shell_graph

from tf_shell.python.discrete_gaussian import DiscreteGaussianParams
from tf_shell.python.discrete_gaussian import sample_centered_gaussian_f
from tf_shell.python.discrete_gaussian import sample_centered_gaussian_l
